<tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="1">1</a></td><td class="hits">1</td><td class="code">import argparse</td></tr><tr class="noCover"><td class="line"><a name="2">2</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="3">3</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="4">4</a></td><td class="hits">1</td><td class="code">def add_verbosity_flag(parser: argparse.ArgumentParser):</td></tr><tr class="noCover"><td class="line"><a name="5">5</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;Add a --verbose/-v flag to an argparse.ArgumentParser.</td></tr><tr class="noCover"><td class="line"><a name="6">6</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="7">7</a></td><td class="hits"></td><td class="code">    Args:</td></tr><tr class="noCover"><td class="line"><a name="8">8</a></td><td class="hits"></td><td class="code">        parser (argparse.ArgumentParser): The argument parser to be updated.</td></tr><tr class="noCover"><td class="line"><a name="9">9</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="10">10</a></td><td class="hits"></td><td class="code">    Example:</td></tr><tr class="noCover"><td class="line"><a name="11">11</a></td><td class="hits"></td><td class="code">        This should be invoked like the following:</td></tr><tr class="noCover"><td class="line"><a name="12">12</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; import uologging</td></tr><tr class="noCover"><td class="line"><a name="13">13</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; import argparse</td></tr><tr class="noCover"><td class="line"><a name="14">14</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; parser &#61; argparse.ArgumentParser()</td></tr><tr class="noCover"><td class="line"><a name="15">15</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; uologging.add_verbosity_flag(parser)</td></tr><tr class="noCover"><td class="line"><a name="16">16</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="17">17</a></td><td class="hits"></td><td class="code">        When parsing args, the verbosity_flag will be set if --verbose/-v is passed!</td></tr><tr class="noCover"><td class="line"><a name="18">18</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; args &#61; parser.parse_args([&#39;-vv&#39;])</td></tr><tr class="noCover"><td class="line"><a name="19">19</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; args.verbosity_flag</td></tr><tr class="noCover"><td class="line"><a name="20">20</a></td><td class="hits"></td><td class="code">        2</td></tr><tr class="noCover"><td class="line"><a name="21">21</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="22">22</a></td><td class="hits"></td><td class="code">        The verbosity_flag is intended to be used as input for set_logging_verbosity().</td></tr><tr class="noCover"><td class="line"><a name="23">23</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="24">24</a></td><td class="hits">1</td><td class="code">    parser.add_argument(</td></tr><tr class="noCover"><td class="line"><a name="25">25</a></td><td class="hits"></td><td class="code">        &#39;-v&#39;, &#39;--verbose&#39;,</td></tr><tr class="noCover"><td class="line"><a name="26">26</a></td><td class="hits"></td><td class="code">        dest&#61;&#39;verbosity_flag&#39;,</td></tr><tr class="noCover"><td class="line"><a name="27">27</a></td><td class="hits"></td><td class="code">        action&#61;&#39;count&#39;,</td></tr><tr class="noCover"><td class="line"><a name="28">28</a></td><td class="hits"></td><td class="code">        default&#61;0,</td></tr><tr class="noCover"><td class="line"><a name="29">29</a></td><td class="hits"></td><td class="code">        help&#61;&#39;Logging verbosity. &#34;-vv&#34; results in maximum logging.&#39;</td></tr><tr class="noCover"><td class="line"><a name="30">30</a></td><td class="hits"></td><td class="code">    )</td></tr><tr class="noCover"><td class="line"><a name="31">31</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="32">32</a></td><td class="hits"></td><td class="code"></td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="33">33</a></td><td class="hits">1</td><td class="code">def get_default_parser():</td></tr><tr class="noCover"><td class="line"><a name="34">34</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;Provides an argparse ArgumentParser configured to take --verbose/-v flag.</td></tr><tr class="noCover"><td class="line"><a name="35">35</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="36">36</a></td><td class="hits"></td><td class="code">    Returns:</td></tr><tr class="noCover"><td class="line"><a name="37">37</a></td><td class="hits"></td><td class="code">        argparse.ArgumentParser: Provides a --verbose/-v flag. Should be used as a &#39;parent parser.&#39;</td></tr><tr class="noCover"><td class="line"><a name="38">38</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="39">39</a></td><td class="hits"></td><td class="code">    Example:</td></tr><tr class="noCover"><td class="line"><a name="40">40</a></td><td class="hits"></td><td class="code">        This should be invoked like the following:</td></tr><tr class="noCover"><td class="line"><a name="41">41</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; import uologging</td></tr><tr class="noCover"><td class="line"><a name="42">42</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; import argparse</td></tr><tr class="noCover"><td class="line"><a name="43">43</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; parser &#61; argparse.ArgumentParser(parents&#61;[uologging.get_default_parser()])</td></tr><tr class="noCover"><td class="line"><a name="44">44</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="45">45</a></td><td class="hits"></td><td class="code">        The parser has been configured with the uologging default_parser as a parent parser.</td></tr><tr class="noCover"><td class="line"><a name="46">46</a></td><td class="hits"></td><td class="code">        When parsing args, the verbosity_flag will be set if --verbose/-v is passed!</td></tr><tr class="noCover"><td class="line"><a name="47">47</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; args &#61; parser.parse_args([&#39;-vv&#39;])</td></tr><tr class="noCover"><td class="line"><a name="48">48</a></td><td class="hits"></td><td class="code">        &gt;&gt;&gt; args.verbosity_flag</td></tr><tr class="noCover"><td class="line"><a name="49">49</a></td><td class="hits"></td><td class="code">        2</td></tr><tr class="noCover"><td class="line"><a name="50">50</a></td><td class="hits"></td><td class="code"></td></tr><tr class="noCover"><td class="line"><a name="51">51</a></td><td class="hits"></td><td class="code">        The verbosity_flag is intended to be used as input for set_logging_verbosity().</td></tr><tr class="noCover"><td class="line"><a name="52">52</a></td><td class="hits"></td><td class="code">    &#34;&#34;&#34;</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="53">53</a></td><td class="hits">1</td><td class="code">    parser &#61; argparse.ArgumentParser(add_help&#61;False)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="54">54</a></td><td class="hits">1</td><td class="code">    add_verbosity_flag(parser)</td></tr><tr class="coverFull" data-html-tooltip="Covered at least once"><td class="line"><a name="55">55</a></td><td class="hits">1</td><td class="code">    return parser</td></tr>